@@ -9,7 +9,8 @@ print("[anapass-python::Example] Read ChipID")
 print("----------------------------------------------")
 
 #TDevice 객체 생성, T5연결하는 Device객체이다.
-device = TDevice(TDevice.Type.T5)
+#device = TDevice(TDevice.Type.T5)
+device = TDevice(TDevice.Type.TESys)
 
 #
 # Python프로그램을 Device를  연결하는 코드이다.
