@@ -249,6 +249,7 @@ class TDevice :
         T5 = 0
         T4 = 0
         T5PacketAnalysis=1
+        TESys=2
 
     class ErrorString(enum.Enum) :
         GetResp="ErrorGetResp"
@@ -395,7 +396,7 @@ class TDevice :
         return bflag
 
     def WriteReg1Byte(this, regAddr, byteOffset, regValue) :
-        ret = TDeviceWriteRegValue1Byte(this.__DeviceHandle, regAddr, byteOffset, c_char(regValue))
+        ret = TDeviceWriteRegValue1Byte(this.__DeviceHandle, regAddr, byteOffset, regValue)
         if ret==1 :
             bflag = True
         else :
